/* cleanwinprofile.js
   cleans windows profile directory
   deletes files recursively for a given modification time
*/



function debug(text)
{
    if(debugPrint==1)
	WScript.Echo(text);
}


/* recursively deletes files in directory
   with a given modification date
   @param startdirname name of the startfolder
   @param regexp regular expression to which the filename should be matched against
          if empty no matching is performed
   @param days days last modification took place
   @param recurse should directories be traversed recursively?
   @param deleteEmptyDirs should empty directories should also be deleted?
          the modification date is not considered for directories
	  does not delete the startdirname folder itself
   @return returns -1 on error, 0 for normal operation and 1 for normal operation and
           no files/directories left on current level
*/
function deleteFiles(startdirname,regexp,days,recurse,deleteEmptyDirs)
{
    var f;
    var startdir;
    var rc;
    var fso = WScript.CreateObject("Scripting.FileSystemObject");
    var dirPath;

    if(!fso.FolderExists(startdirname))
	return -1;

    startdir = fso.getFolder(startdirname);

    // recurse into deeper directories
    if(recurse==1)
    {
	var dirs;
	var subFolders = startdir.SubFolders;
	
	if(subFolders.count>0)
	{
	    dirs = new Enumerator(subFolders);

	    for(;!dirs.atEnd(); dirs.moveNext())
	    {
		var dummy;
		d = dirs.item();
		dirPath = d.path;
		rc = deleteFiles(dirPath,regexp,days,recurse,deleteEmptyDirs);

		if(deleteEmptyDirs == 1 && rc == 1)
		{
		    debug("no files left in directory " + dirPath + " deleting ...");
		    try
		    {
			fso.deleteFolder(dirPath,false);
		    }
		    catch(e)
		    {
			debug("Could not delete directory " + dirPath + ".\r\n This should not happen.");
		    }
		}
	    }
	}
    }


    

    var files = new Enumerator(startdir.files);
    var now = new Date();
    var startDate;
    
    // date calculation in JavaScript is in microseconds
    startDate = now - days * 86400 * 1000;

    for(files.moveFirst();!files.atEnd(); files.moveNext())
    {
	f = files.item();
	fileDate = f.DateLastModified;
	if(f.DateLastModified < startDate)
	{
	    if(regexp.length>0)
	    {
		if(f.Name.search(regexp)>=0)
		{
		    debug(f.path + " " + f.DateLastModified);
		    try
		    {
			fso.deleteFile(f.path,true);
		    }
		    catch(e)
		    {
			debug("Error: Could not delete file " + f.path + ".\r\n This should not happen.");
		    }
		}
	    }
	    else
	    {
		debug(f.path + " " + f.DateLastModified);
		try
		{
		    fso.deleteFile(f.path,true);
		}
		catch(e)
		{
		    debug("Error: Could not delete file " + f.path + ".\r\n This should not happen.");
		}

	    }
	}
    }

    // are all directory entries deleted? is this directory empty?
    if(startdir.files.count == 0 && startdir.subFolders.count == 0)
    {
	return 1;
    }
    else
    {
	return 0;
    }
    
    

}




var WshShell = WScript.CreateObject("WScript.Shell");
var fso = WScript.CreateObject("Scripting.FileSystemObject");
var profileDirname;
var debugPrint = 0;


var appDataDirname = WshShell.SpecialFolders("AppData");
var localSettingsDirname = WshShell.SpecialFolders("AppData");
var WshEnv = WshShell.Environment("Process");
var profileDirname = WshEnv("userprofile");

deleteFiles(fso.BuildPath(appDataDirname,"Sun\\Java\\Deployment\\Cache"),"",7,1,0);

// leave it longer, for debug purposes (Mozillas Talkback)
deleteFiles(fso.BuildPath(appDataDirname,"Talkback"),"",28,1,1);


deleteFiles(fso.BuildPath(appDataDirname,"Microsoft\\Office\\Zuletzt verwendet"),"",28,0,0);

deleteFiles(WshShell.SpecialFolders("Recent"),"",28,0,0);


// cookie like settings for flash player and cache
deleteFiles(fso.BuildPath(appDataDirname,"Macromedia\\Flash Player"),"",7,1,1);



//deleteFiles("C:\\temp\\testdocdir\\0001","",-1,1,1);

deleteFiles(fso.buildPath(profileDirname,"Lokale Einstellungen\\Temp"),"",4,1,1);

// delete whole dir, it isn't important and otherwise we would need
// to parse index.dat to not leave corrupted cache
// although cookies are displayed underneath this directory in explorer they are not
// stored here and are safe to this delete operation
deleteFiles(fso.buildPath(profileDirname,"Lokale Einstellungen\\Temporary Internet Files"),"",-1,1,1);


//todo autorestore dir of ms office
deleteFiles(fso.BuildPath(appDataDirname,"Microsoft\\Word"),".*tmp|.*wbk",7,0,0);



